.. _io:

Input / Output
==============

Introduction
------------

This module contains functions to read input data and write IRFs in GADF format.

Currently there is only support for reading EventDisplay DL2 FITS files,
which were converted from the ROOT files by using `EventDisplay DL2 conversion scripts <https://github.com/Eventdisplay/Converters/>`_.


Reference/API
-------------

.. automodapi:: pyirf.io
   :no-inheritance-diagram:
